# May-03-2024
# glbl.py


result_name: str = '_RESULT_'

path_test_mnist: str = ''
path_train_0_mnist: str = ''
path_train_1_mnist: str = ''
path_train_2_mnist: str = ''
path_train_3_mnist: str = ''
path_train_4_mnist: str = ''
path_train_5_mnist: str = ''
path_train_6_mnist: str = ''
path_train_7_mnist: str = ''
path_train_8_mnist: str = ''
path_train_9_mnist: str = ''

path_test_canon: str = ''
path_train_0_canon: str = ''
path_train_1_canon: str = ''
path_train_2_canon: str = ''
path_train_3_canon: str = ''
path_train_4_canon: str = ''
path_train_5_canon: str = ''
path_train_6_canon: str = ''
path_train_7_canon: str = ''
path_train_8_canon: str = ''
path_train_9_canon: str = ''
